@@ -2,18 +2,15 @@
 #'
 #' Abstract class for data in the package Luminescence
 #'
-#'
 #' @name TLum-class
 #' @rdname TLum-class
 #'
-#' @docType class
 #' @note \code{TLum} is a virtual class.
+#'
 #' @keywords classes
 #'
 #' @author David Strebler
 #'
 #' @exportClass TLum
 
-setClass("TLum",
-         representation()
-         )
+setClass(Class = "TLum")
